/**
* Copyright (c) 2001-2022 by PDFTron Systems Inc. All Rights Reserved.
* Consult legal.txt regarding legal and license information.
 */
#ifndef   H_PDF2IMAGEAPI
#define   H_PDF2IMAGEAPI

/** 
 * The calling convention to use for all calls across the "library boundary."
 */
#ifdef _WIN32
  #define PDF2IMAGE_API_CALL __stdcall
	#ifdef PDF2IMAGE_API_EXPORT
		#define PDF2IMAGE_API(type) __declspec(dllexport) type PDF2IMAGE_API_CALL 
	#else
		#define PDF2IMAGE_API(type) __declspec(dllimport) type PDF2IMAGE_API_CALL 
	#endif
#else
  #define PDF2IMAGE_API_CALL
 	#ifdef PDF2IMAGE_API_EXPORT
		#define PDF2IMAGE_API(type) __attribute__ ((visibility("default"))) type PDF2IMAGE_API_CALL 
	#else
		#define PDF2IMAGE_API(type) type PDF2IMAGE_API_CALL 
	#endif
#endif

#ifdef __cplusplus
extern "C" {
#endif

/** 
 * 'mode' identifier passed in PDF2ImageCallback.
 * The 'mode' can be used to determine whether a message is an error or 
 * a progress message.
 */ 
#define PDF2IMAGE_ERROR		   1 /* Show the error message  */
#define PDF2IMAGE_MSG		   2 /* Report the message      */
#define PDF2IMAGE_GETPASS	   3 /* Get the password        */
#define PDF2IMAGE_OUT_FILENAME 4 /* Reports the Saved File Names */

typedef char* PDF2IMAGE_API_CALL PDF2ImageCallback(int mode, char* msg, void* user_data);

/**
 * Initialize PDF2Image with registration and license information.
 * Although PDF2ImageInit is typically called only once (e.g. during the program 
 * startup), it can also be called multiple times without side effects. 
 *
 * The first parameter is your username, the second parameter is your company name, 
 * and the last parameter is the license key supplied with your registration information.
 */
PDF2IMAGE_API(int)
PDF2ImageInit(char* user_name, char* company, char* license_key);

/** 
 * Return codes for PDF2ImageRun function.
 */ 
#define PDF2IMAGE_OK             0  /* No errors */
#define PDF2IMAGE_ERR            1  /* Unspecified error */
#define PDF2IMAGE_ERR_BADKEY     2  /* Bad license key */
#define PDF2IMAGE_ERR_DIRCREATE  3  /* Failed to create the output file/directory */
#define PDF2IMAGE_ERR_READINGPDF 4  /* Failed to read input document */
#define PDF2IMAGE_ERR_PASSWORD   5  /* The password required to open PDF is incorrect */
#define PDF2IMAGE_ERR_CONVERT    6  /* A conversion error */
#define PDF2IMAGE_ERR_NOCONNECT  7  /* Can't connect to the server */


/**
 * Execute PDF2Image command string.
 * 
 * PDF2ImageRun can be called multiple times to process PDF documents or folders 
 * with PDF documents. The function is completely thread safe, so it is possible to 
 * run many PDF2Image threads at the same time.
 * 
 * @param command_str PDF2Image command string. For a detailed explanation of 
 * all options and syntax, please refer to section 4 in PDF2Image SDK Manual. 
 *
 * @param funct (optional) a pointer to the callback function used to report error 
 * as well as other messages. 
 *
 * @param user_data (optional) a pointer to custom data that you may want to 
 * pass to the callback function. NULL if you don't need to pass custom data.
 *
 * @return error code. A non-zero value indicates that an error was encountered.
 */
PDF2IMAGE_API(int)
PDF2ImageRun(char* command_str, PDF2ImageCallback* funct, void* user_data);

#ifdef __cplusplus
}
#endif

#endif  /* H_PDF2IMAGEAPI */
